@@ -40,23 +40,23 @@ def update_pictures_in_db(pic_dir: str, connections_str: str):
 def _clean_db(session) -> bool:
     all_pics = session.query(PictureData).all()
     num_deleted = 0
-    for count, pic in enumerate(all_pics, 1):
+    for pic in all_pics:
         if not os.path.exists(pic.absolute_path):
             session.delete(pic)
             session.commit()
             num_deleted += 1
             log.debug(f"Deleted {pic.absolute_path} from db.")
-        if count % 1000 == 0:
-            log.info(f"Checked {count} db entries for missing hdd files.")
-    log.info(f"Deleted {num_deleted} entries from db.")
+    log.info(
+        f"Checked {len(all_pics)} pictures and deleted {num_deleted} entries from db."
+    )
     return num_deleted > 0
 
 
 def _add_and_update_pics(pic_file_gen, session) -> bool:
     num_changed = 0
-    for count, pic_file in enumerate(pic_file_gen, 1):
-        if count % 1000 == 0:
-            log.info(f"Checked {count} files for necessary db updates.")
+    num_checked = 0
+    for pic_file in pic_file_gen:
+        num_checked += 1
         try:
             pic_by_path = _get_pic_by_path(session, pic_file)
             # Is present
@@ -99,7 +99,9 @@ def _add_and_update_pics(pic_file_gen, session) -> bool:
                 f"Exception while trying to update db with {pic_file.path}.", exc_info=e
             )
             session.rollback()
-        log.info(f"{num_changed} pics added or updated to/in db.")
+    log.info(
+        f"Checked {num_checked} files and {num_changed} pics added or updated to/in db."
+    )
     return num_changed > 0
 
 
